test_name "CVE 2013-1654 SSL2 Downgrade of Master connection" do

  def suitable?(host)
    ruby = host['puppetbindir'] ? "#{host['puppetbindir']}/ruby" : 'ruby'
    cmd = <<END
#{ruby} -ropenssl -e "puts OpenSSL::SSL::SSLContext::METHODS.include?(:SSLv2)"
END
    on(host, cmd).stdout.chomp == "true"
  end

  def suitable_agent?(agent)
    res = on( agent,
             'openssl -v', :acceptable_exit_codes => (0..255).to_a )
    res.exit_code == 0
  end

  suitable_agent = agents.select {|agent| suitable_agent?( agent ) }.first

  if suitable?( master )
    with_puppet_running_on( master, {} ) do

      certfile = on(suitable_agent, puppet_agent("--configprint hostcert")).stdout.chomp
      keyfile = on(suitable_agent, puppet_agent("--configprint hostprivkey")).stdout.chomp
      cafile = on(suitable_agent, puppet_agent("--configprint localcacert")).stdout.chomp

      openssl_call = "openssl s_client -connect #{master}:8140 " +
                     "-cert \"#{certfile}\" -key \"#{keyfile}\" " +
                     "-CAfile \"#{cafile}\" -ssl2 -msg < /dev/null"

      on(suitable_agent, openssl_call, :acceptable_exit_codes => (0..255)) do |test|
        assert_match /CLIENT-HELLO/, test.stdout
        assert_no_match /SERVER-HELLO/, test.stdout
      end
    end
  else
    logger.debug( "Not testing master as SSLv2 isn't available to it" )
  end
end
